@@ -5,6 +5,8 @@
 
 #include "qwayland-server-treeland-dde-shell-v1.h"
 
+#include "helper.h"
+
 #include <woutput.h>
 
 #include <qwcompositor.h>
@@ -12,6 +14,8 @@
 #include <qwoutput.h>
 #include <qwseat.h>
 
+#include <wayland-server.h>
+
 #define TREELAND_DDE_SHELL_MANAGER_V1_VERSION 1
 
 static QList<DDEShellSurfaceInterface *> s_shellSurfaces;
@@ -45,6 +49,12 @@ protected:
                                                                   uint32_t id) override;
     void treeland_dde_shell_manager_v1_get_treeland_lockscreen(Resource *resource,
                                                                uint32_t id) override;
+    void treeland_dde_shell_manager_v1_set_xwindow_position_relative(Resource *resource,
+                                                                     uint32_t callback,
+                                                                     uint32_t wid,
+                                                                     struct ::wl_resource *anchor,
+                                                                     wl_fixed_t dx,
+                                                                     wl_fixed_t dy) override;
 };
 
 void DDEShellManagerInterfaceV1Private::treeland_dde_shell_manager_v1_get_treeland_lockscreen(
@@ -69,6 +79,20 @@ void DDEShellManagerInterfaceV1Private::treeland_dde_shell_manager_v1_get_treela
     Q_EMIT q->lockScreenCreated(lockScreen);
 }
 
+void DDEShellManagerInterfaceV1Private::treeland_dde_shell_manager_v1_set_xwindow_position_relative(Resource *resource,
+                                                                                                    uint32_t callback,
+                                                                                                    uint32_t wid,
+                                                                                                    struct ::wl_resource *anchor,
+                                                                                                    wl_fixed_t dx,
+                                                                                                    wl_fixed_t dy)
+{
+    WSurface *wsurface = WSurface::fromHandle(qw_surface::from_resource(anchor));
+    uint32_t ok = (wsurface && Helper::instance()->setXWindowPositionRelative(wid, wsurface, dx, dy)) ? 0 : 1;
+    wl_resource *cb = wl_resource_create(resource->client(), &wl_callback_interface, 1, callback);
+    wl_callback_send_done(cb, ok);
+    wl_resource_destroy(cb);
+}
+
 DDEShellManagerInterfaceV1Private::DDEShellManagerInterfaceV1Private(DDEShellManagerInterfaceV1 *_q)
     : q(_q)
 {
